@@ -1,9 +1,12 @@
 import os
+import re
 import tokenize
 from string import ascii_lowercase, ascii_uppercase, digits
 
 import pkg_resources
 
+NOQA_REGEX = re.compile(r"#[\s]*noqa:[\s]*[\D]+[\d]+")
+
 
 # Really simple detection function
 def detect_case(name):
@@ -79,7 +82,7 @@ def get_code(token_type):
 
 class SpellCheckPlugin:
     name = "flake8-spellcheck"
-    version = "0.18.0"
+    version = "0.20.0"
 
     def __init__(self, tree, filename="(none)", file_tokens=None):
         self.file_tokens = file_tokens
@@ -160,16 +163,23 @@ class SpellCheckPlugin:
         for token_info in self.file_tokens:
             yield from self._parse_token(token_info)
 
+    def _is_valid_comment(self, token_info):
+        return (
+            token_info.type == tokenize.COMMENT
+            and "comments" in self.spellcheck_targets
+            # Ensure comment is non-empty, github.com/MichaelAquilina/flake8-spellcheck/issues/34
+            and token_info.string.strip() != "#"
+            # Ignore flake8 pragma comments
+            and token_info.string.lstrip("#").split()[0] != "noqa:"
+        )
+
     def _parse_token(self, token_info):
         if token_info.type == tokenize.NAME and "names" in self.spellcheck_targets:
             value = token_info.string
-        elif (
-            token_info.type == tokenize.COMMENT
-            and "comments" in self.spellcheck_targets
-            # ignore flake8 pragma comments
-            and token_info.string.lstrip("#").split()[0] != "noqa:"
-        ):
-            value = token_info.string.lstrip("#")
+        elif self._is_valid_comment(token_info):
+            # strip out all `noqa: [code]` style comments so they aren't erroneously checked
+            # see https://github.com/MichaelAquilina/flake8-spellcheck/issues/36 for info
+            value = NOQA_REGEX.sub("", token_info.string.lstrip("#"))
         else:
             return
 
